@@ -13,6 +13,7 @@ extern SEXP R_curl_fetch_memory(SEXP, SEXP, SEXP);
 extern SEXP R_curl_getdate(SEXP);
 extern SEXP R_curl_version(void);
 extern SEXP R_download_curl(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
+extern SEXP R_findport(SEXP candidates);
 extern SEXP R_get_handle_clength(SEXP);
 extern SEXP R_get_handle_cookies(SEXP);
 extern SEXP R_get_handle_mtime(SEXP);
@@ -37,6 +38,7 @@ extern SEXP R_multi_setopt(SEXP, SEXP, SEXP, SEXP);
 extern SEXP R_new_file_writer(SEXP);
 extern SEXP R_new_handle(void);
 extern SEXP R_nslookup(SEXP, SEXP);
+extern SEXP R_parse_url(SEXP, SEXP);
 extern SEXP R_proxy_info(void);
 extern SEXP R_split_string(SEXP, SEXP);
 extern SEXP R_total_handles(void);
@@ -52,6 +54,7 @@ static const R_CallMethodDef CallEntries[] = {
     {"R_curl_getdate",        (DL_FUNC) &R_curl_getdate,        1},
     {"R_curl_version",        (DL_FUNC) &R_curl_version,        0},
     {"R_download_curl",       (DL_FUNC) &R_download_curl,       6},
+    {"R_findport",            (DL_FUNC) &R_findport,            1},
     {"R_get_handle_clength",  (DL_FUNC) &R_get_handle_clength,  1},
     {"R_get_handle_cookies",  (DL_FUNC) &R_get_handle_cookies,  1},
     {"R_get_handle_mtime",    (DL_FUNC) &R_get_handle_mtime,    1},
@@ -63,7 +66,6 @@ static const R_CallMethodDef CallEntries[] = {
     {"R_handle_getheaders",   (DL_FUNC) &R_handle_getheaders,   1},
     {"R_handle_reset",        (DL_FUNC) &R_handle_reset,        1},
     {"R_handle_setform",      (DL_FUNC) &R_handle_setform,      2},
-    {"R_handle_setheaders",   (DL_FUNC) &R_handle_setheaders,   2},
     {"R_handle_setopt",       (DL_FUNC) &R_handle_setopt,       3},
     {"R_option_types",        (DL_FUNC) &R_option_types,        0},
     {"R_multi_add",           (DL_FUNC) &R_multi_add,           5},
@@ -76,6 +78,7 @@ static const R_CallMethodDef CallEntries[] = {
     {"R_new_file_writer",     (DL_FUNC) &R_new_file_writer,     1},
     {"R_new_handle",          (DL_FUNC) &R_new_handle,          0},
     {"R_nslookup",            (DL_FUNC) &R_nslookup,            2},
+    {"R_parse_url",           (DL_FUNC) &R_parse_url,           2},
     {"R_proxy_info",          (DL_FUNC) &R_proxy_info,          0},
     {"R_split_string",        (DL_FUNC) &R_split_string,        2},
     {"R_total_handles",       (DL_FUNC) &R_total_handles,       0},
@@ -86,17 +89,17 @@ static const R_CallMethodDef CallEntries[] = {
 };
 
 void switch_to_openssl_on_vista(void);
-CURLM *multi_handle = NULL;
+CURLM *shared_multi_handle = NULL;
 
 attribute_visible void R_init_curl(DllInfo *info) {
   switch_to_openssl_on_vista();
   curl_global_init(CURL_GLOBAL_DEFAULT);
-  multi_handle = curl_multi_init();
+  shared_multi_handle = curl_multi_init();
   R_registerRoutines(info, NULL, CallEntries, NULL, NULL);
   R_useDynamicSymbols(info, FALSE);
 }
 
 attribute_visible void R_unload_curl(DllInfo *info) {
-  curl_multi_cleanup(multi_handle);
+  curl_multi_cleanup(shared_multi_handle);
   //curl_global_cleanup();
 }
