@@ -1,5 +1,5 @@
 /* Non-blocking drop-in replacement for curl_easy_perform with support for
- * R interruptions. Based on: https://curl.haxx.se/libcurl/c/multi-single.html
+ * R interruptions. Based on: https://curl.se/libcurl/c/multi-single.html
  */
 
 #include <Rinternals.h>
@@ -10,21 +10,38 @@ void check_interrupt_fn(void *dummy) {
   R_CheckUserInterrupt();
 }
 
-int pending_interrupt() {
+int pending_interrupt(void) {
   return !(R_ToplevelExec(check_interrupt_fn, NULL));
 }
 
+static int str_starts_with(const char *a, const char *b) {
+  if(strncmp(a, b, strlen(b)) == 0) return 1;
+  return 0;
+}
+
 /* created in init.c */
-CURLM * multi_handle;
+extern CURLM * shared_multi_handle;
 
 /* Don't call Rf_error() until we remove the handle from the multi handle! */
 CURLcode curl_perform_with_interrupt(CURL *handle){
   /* start settings */
   CURLcode status = CURLE_FAILED_INIT;
+  CURLM * temp_multi_handle = NULL;
+  CURLM * multi_handle = NULL;
   int still_running = 1;
 
+  /* Do not reuse FTP connections, because it is buggy */
+  /* For example https://github.com/jeroen/curl/issues/348 */
+  const char *effective_url = NULL;
+  curl_easy_getinfo(handle, CURLINFO_EFFECTIVE_URL, &effective_url);
+  if(effective_url && str_starts_with(effective_url, "ftp")){
+    temp_multi_handle = curl_multi_init();
+    multi_handle = temp_multi_handle;
+  } else {
+    multi_handle = shared_multi_handle;
+  }
+
   if(CURLM_OK != curl_multi_add_handle(multi_handle, handle)){
-    curl_multi_cleanup(multi_handle);
     return CURLE_FAILED_INIT;
   }
 
@@ -35,20 +52,12 @@ CURLcode curl_perform_with_interrupt(CURL *handle){
       break;
     }
 
-#ifdef HAS_MULTI_WAIT
-    /* wait for activity, timeout or "nothing" */
     int numfds;
     if(curl_multi_wait(multi_handle, NULL, 0, 1000, &numfds) != CURLM_OK)
       break;
-#endif
-
-    /* Required by old versions of libcurl */
-    CURLMcode res = CURLM_CALL_MULTI_PERFORM;
-    while(res == CURLM_CALL_MULTI_PERFORM)
-      res = curl_multi_perform(multi_handle, &(still_running));
 
     /* check for multi errors */
-    if(res != CURLM_OK)
+    if(curl_multi_perform(multi_handle, &(still_running)) != CURLM_OK)
       break;
   }
 
@@ -66,5 +75,7 @@ CURLcode curl_perform_with_interrupt(CURL *handle){
 
   /* cleanup first */
   curl_multi_remove_handle(multi_handle, handle);
+  if(temp_multi_handle)
+    curl_multi_cleanup(temp_multi_handle);
   return status;
 }
