@@ -15,6 +15,23 @@ multiref *get_multiref(SEXP ptr){
   return mref;
 }
 
+/* retrieves CURLM from connections as well as pools */
+CURLM *get_curlm(SEXP ptr){
+  CURLM *multi;
+  if(Rf_inherits(ptr, "curl")){
+    ptr = Rf_getAttrib(ptr, Rf_install("conn_id"));
+    if (TYPEOF(ptr) != EXTPTRSXP)
+      Rf_error("pool ptr is not a curl connection");
+    multi = (CURLM*) R_ExternalPtrAddr(ptr);
+    if(!multi)
+      Rf_error("CURLM pointer is dead");
+  } else {
+    multiref *mref = get_multiref(ptr);
+    multi = mref->m;
+  }
+  return multi;
+}
+
 void multi_release(reference *ref){
   /* Release the easy-handle */
   CURL *handle = ref->handle;
@@ -247,8 +264,7 @@ SEXP R_multi_list(SEXP pool_ptr){
 }
 
 SEXP R_multi_fdset(SEXP pool_ptr){
-  multiref *mref =  get_multiref(pool_ptr);
-  CURLM *multi = mref->m;
+  CURLM *multi = get_curlm(pool_ptr);
   fd_set read_fd_set, write_fd_set, exc_fd_set;
   int max_fd, i, num_read = 0, num_write = 0, num_exc = 0;
   int *pread, *pwrite, *pexc;
